HasOne

Struct HasOne 

pub struct HasOne<T> { /* private fields */ }
A lazily-loaded has-one association.

HasOne<T> wraps an optional T that is populated when the association is eagerly loaded (via include) or accessed through a generated relation accessor. Before loading, calling get panics.

This type appears as a field on model structs for has-one relations.

Implementations

Source

impl<T: Relation> HasOne<T>

pub fn get(&self) -> &T

Returns a reference to the loaded associated record.

Panics

Panics if the association has not been loaded.

pub fn is_unloaded(&self) -> bool

Returns true if the association has not been loaded yet.

pub fn unload(&mut self)

Clear the loaded value, returning this association to the unloaded state.